@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -35,9 +35,10 @@ from google.cloud.orchestration.airflow.service_v1beta1.services.image_versions
     pagers,
 )
 from google.cloud.orchestration.airflow.service_v1beta1.types import image_versions
-from .transports.base import ImageVersionsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ImageVersionsGrpcAsyncIOTransport
+
 from .client import ImageVersionsClient
+from .transports.base import DEFAULT_CLIENT_INFO, ImageVersionsTransport
+from .transports.grpc_asyncio import ImageVersionsGrpcAsyncIOTransport
 
 
 class ImageVersionsAsyncClient:
@@ -217,9 +218,9 @@ class ImageVersionsAsyncClient:
 
             from google.cloud.orchestration.airflow import service_v1beta1
 
-            def sample_list_image_versions():
+            async def sample_list_image_versions():
                 # Create a client
-                client = service_v1beta1.ImageVersionsClient()
+                client = service_v1beta1.ImageVersionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_v1beta1.ListImageVersionsRequest(
@@ -229,7 +230,7 @@ class ImageVersionsAsyncClient:
                 page_result = client.list_image_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -291,12 +292,20 @@ class ImageVersionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListImageVersionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
